pub struct EmojiParserOptions {
pub blacklist: Option<Rc<AsciiWordSet>>,
}Expand description
Options for the emoji parser.
Fields
blacklist: Option<Rc<AsciiWordSet>>An optional set of shortcodes to ignore when parsing emojis. If provided, any shortcode in this set will not be parsed as an emoji.